|RTD| |Travis Status| |AppVeyor status| |CircleCI| |Coverage Status|

About
-----

This is a BSD-licensed HEALPix package developed by the Astropy project
and based on C code written by Dustin Lang in `astrometry.net <http://astrometry.net/>`__. See the
`Documentation <http://astropy-healpix.readthedocs.io>`__ for
information about installing and using this package.

.. |Travis Status| image:: https://travis-ci.org/astropy/astropy-healpix.svg
   :target: https://travis-ci.org/astropy/astropy-healpix?branch=master
.. |AppVeyor status| image:: https://ci.appveyor.com/api/projects/status/5kxwb47o2umy370m/branch/master?svg=true
   :target: https://ci.appveyor.com/project/Astropy/astropy-healpix/branch/master
.. |CircleCI| image:: https://circleci.com/gh/astropy/astropy-healpix.svg?style=svg
   :target: https://circleci.com/gh/astropy/astropy-healpix
.. |Coverage Status| image:: https://coveralls.io/repos/astropy/astropy-healpix/badge.svg
   :target: https://coveralls.io/r/astropy/astropy-healpix
.. |RTD| image:: https://readthedocs.org/projects/astropy-healpix/badge/?version=latest
   :target: http://astropy-healpix.readthedocs.io/en/latest/?badge=latest
